Welcome to the Aind Watchdog Service documentation!
=========================================================

.. mdinclude:: ../README.md

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   self
   aind-watchdog-service
   models
   GitHub Source Code <https://github.com/AllenNeuralDynamics/aind-watchdog-service>

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
